#
# spec file for package ncdu
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           ncdu
Version:        1.21
Release:        1.2
Summary:        NCurses Disk Usage
License:        MIT
URL:            https://dev.yorhel.nl/ncdu/
Source0:        https://dev.yorhel.nl/download/%{name}-%{version}.tar.gz
Source1:        https://dev.yorhel.nl/download/%{name}-%{version}.tar.gz.asc
Source2:        https://yorhel.nl/key.asc#/%{name}.keyring
BuildRequires:  pkgconfig(ncurses)

%description
ncdu (NCurses Disk Usage) is a curses-based version of
the well-known 'du', and provides a fast way to see what
directories are using your disk space.

%prep
%autosetup

%build
%configure
%make_build

%install
%make_install

%check
%make_build check

%files
%license COPYING
%doc ChangeLog README
%{_bindir}/%{name}
%{_mandir}/man?/%{name}.?%{?ext_man}

%changelog
* Wed Nov 20 2024 ecsos <ecsos@opensuse.org>
- Update to 1.21:
  - Perform tilde expansion on paths in the config file (from 2.7)
  - Fix JSON import of escaped UTF-16 surrogate pairs (from 2.7)
  - Fix displaying and exporting zero values when extended info is not available (from 2.6)
  - Fix JSON export and import of the “other filesystem” flag (from 2.5)
* Wed May  1 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.20:
  * Revert default color scheme back to ‘off’
  * Rewrite man page in mdoc, drop pod2man dependency
* Thu Mar 21 2024 Richard Rahl <rrahl0@proton.me>
- update to 1.19
  - Fix typo in --exclude-from argument
  - Add --(enable|disable)-natsort options
  - Add indicator to apparent size/disk usage selection in the footer
- add url for keyring
- use pkgconfig
- look for all manpages
* Mon May  1 2023 Eyad Issa <eyadlorenzo@gmail.com>
- Update to 1.18.1
  - 1.18.1
    Fix build on non-Linux platforms
  - 1.18
  - Fix ‘dark-bg’ color scheme to actually have a dark background
  - Backport configuration file support from 2.x
  - Backport many new CLI options from 2.x
  - Negation of existing flags: –no-si, –no-confirm-quit, –no-follow-symlinks, –include-caches, –include-kernfs
  - –[no-]extended in addition to -e
  - –one-file-system and –cross-file-system in addition to -x
  - –slow-ui-updates, –fast-ui-updates in addition to -q
  - Column visibility options: –(show|hide)-(hidden|itemcount|mtime|graph|percent)
  - Sorting: –sort, –[no-]group-directories-first
  - Feature selection: –(enable|disable)-(shell|delete|refresh)
  - Deletion confirmation: –[no-]confirm-delete
  - Hidden file visibility: –show-hidden, –hide-hidden
  - Size display: –apparent-size, –disk-usage
  - 1.17
  - Add ‘dark-bg’ color scheme and use that by default
  - Use natural sort order when sorting by file name
  - Improve compatibility with C89 environments
  - Fix wrong assumption about errno not being set by realloc()
* Fri Nov  5 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 1.16
  * Increase width of size bar depending on terminal size
  * Set/increment $NCDU_LEVEL variable when spawning a shell
  * Indicate whether apparent size or disk usage is being displayed
  * Display setuid, setgid and sticky bits in file flags in extended mode
  * Fix error handling while reading --exclude-from file
  * Improve JSON import to allow for several future extensions to the format
  * Export link count in JSON dumps
  * Don't export inode in JSON dumps for non-hardlinks
* Thu Aug 20 2020 Dirk Mueller <dmueller@suse.com>
- update to 1.15.1
  - (Linux) Fix build on older Linux systems (Christian Göttsche)
  - (MacOS) Revert "Exclude firmlinks by default" behavior (until we have a better solution)
  - (MacOS) Add --exclude-firmlinks option to opt-in to the above behavior
* Sat Jun  6 2020 Matthias Eliasson <elimat@opensuse.org>
- Update to version 1.15
  * (Linux) Add --exclude-kernfs option to exclude pseudo filesystems (Christian Göttsche)
  * Fix bug in calculating the apparent size of directories containing hardlinks
  * Fix integer overflow with directories containing >2GiB worth of file names
  * Fix yet another possible 100%% CPU bug when losing terminal
- run spec-cleaner
* Sat May 18 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 1.14
  * Add mtime display and sorting
  * Add (limited) --follow-symlinks option
  * Display larger file counts in browser UI
  * Add -V, --version, and --help alias flags
  * Fix crash when attempting to sort an empty directory
  * Fix 100%% CPU bug when ncdu loses the terminal
  * Fix '--color=off' flag
  * Fix some typos
* Wed Feb  7 2018 avindra@opensuse.org
- Update to 1.13
  * Add "extended information" mode and -e flag
  * Add file mode, modification time and uid/gid to info window
    with -e
  * Add experimental color support and --color flag
  * Add -rr option to disable shell spawning
  * Remove directory nesting limit on file import
  * Fix handling of interrupts during file import
- cleanup with spec-cleaner
- use https urls
* Sat Dec 31 2016 matthias.eliasson@gmail.com
- Update to 1.12
  * Add NCDU_SHELL environment variable
  * Add --confirm-quit flag
  * Fix compilation due to missing sys/wait.h
- Remove include_sys_wait.patch. Fixed upstream
* Thu Apr 28 2016 toddrme2178@gmail.com
- Update to 1.11
  * Added 'b' key to spawn shell in the current directory
  * Support scanning (and refreshing) of empty directories
  * Added --si flag for base 10 prefixes
  * Fix toggle dirs before files
- Spec file cleanups
- Add include_sys_wait.patch.  Fixes building on earlier distros.
  The patch is includes upstream and should be in the next release.
  Please see:
  + https://dev.yorhel.nl/ncdu/bug/70
  + https://g.blicky.net/ncdu.git/commit/?id=29f347c19cb7ad17c4b401e1d984fce8eafaaafa
* Sat Aug 31 2013 lazy.kent@opensuse.org
- Update to 1.10.
  * Added 'c' key to display item counts.
  * Added 'C' key to order by item counts.
  * Added CACHEDIR.TAG support and --exclude-caches option.
  * Use locale-dependent thousand separator.
  * Clip file/dir sizes to 8 EiB minus one byte.
  * Fix buffer overflow when formatting huge file sizes.
- Verify GPG signature.
* Thu Oct 18 2012 pascal.bleser@opensuse.org
- update to 1.9:
  * added option to dump scanned directory information to a file (-o)
  * added option to load scanned directory information from a file (-f)
  * added multiple scan and load interfaces (-0,-1,-2)
  * fit loading and error windows to the terminal width (#13)
  * fix symlink resolving bug (#18)
  * fix path display when scanning an empty directory (#15)
  * fix hang when terminal is resized to a too small size while loading
* Thu Nov  3 2011 pascal.bleser@opensuse.org
- moved from Packman/Extra to utilities on build.o.o
* Thu Nov  3 2011 pascal.bleser@opensuse.org
- update to 1.8:
  * use hash table to speed up hard link detection
  * added read-only option (-r)
  * use KiB instead of kiB (sf#3399279)
* Fri Aug 13 2010 toni@links2linux.de
- update to 1.7
- This release has improved handling of hard links, a more intuitive
  multi-page browser, and various performance improvements and bugfixes.
* Fri Oct 23 2009 toni@links2linux.de
- update to 1.6
- This release adds hard link detection, VIM keybindings, improved support for
  non-ASCII characters in filenames, and fixes for several bugs.
* Sun May  3 2009 toni@links2linux.de
- update to 1.5
* Mon Dec 17 2007 marekstopka@gmail.com
- new package created
